@@ -31,6 +31,8 @@
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 #include <curl/curl.h>
+#include <libintl.h>
+#include <locale.h>
 
 typedef struct _DroplineData DroplineData;
 typedef struct _HTTPMem HTTPMem;
@@ -259,25 +261,25 @@ update_alert (DroplineData *data, gint status)
 	case STATUS_IDLE:
 	{
 		pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/dropline/applet-idle.png", NULL);
-		tip = "No Dropline GNOME updates are available";
+		tip = _("No Dropline GNOME updates are available");
 		break;
 	}
 	case STATUS_CHECKING:
 	{
 		pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/dropline/applet-checking.png", NULL);
-		tip = "Looking for new Dropline GNOME software...";
+		tip = _("Looking for new Dropline GNOME software...");
 		break;
 	}
 	case STATUS_AVAILABLE:
 	{
 		pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/dropline/applet-available.png", NULL);
-		tip = "New Dropline GNOME software is available";
+		tip = _("New Dropline GNOME software is available");
 		break;
 	}
 	default:
 	{
 		pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/dropline/applet-error.png", NULL);
-		tip = "Error while looking for updates";
+		tip = _("Error while looking for updates");
 		break;
 	}
 	}
@@ -379,7 +381,7 @@ dropline_update_cb (BonoboUIComponent *uic, DroplineData *data, const gchar *ver
 {
 	update_alert (data, STATUS_IDLE);
 	
-	gnome_execute_terminal_shell (NULL, "dropline-installer --upgrade");
+	gnome_execute_terminal_shell (NULL, "dropline-installer");
 		
 	return;
 }
